# Quickstart

In the quickstart, you should walk through the basics of using the project.
Ideally, this should be done using a simple example that is easy to follow and requires the minimum amount of dependencies.

```python
from example_project.subpackage import example

result = example.submodule_function(1, 2)
print(result)
```
